# TimePeriodCondition

This condition is true if the request is within a certain timeperiod 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**condition_type** | **str** | The discriminator for the condition | 
**timezone** | **str** | IANA timezone for this timeperiod  | 
**days** | **[str]** | A list of this time condition is valid for. If omitted, all days are assumed. In UTC.  | [optional] 
**start_time_of_day** | [**TimeOfDayCondition**](TimeOfDayCondition.md) |  | [optional] 
**end_time_of_day** | [**TimeOfDayCondition**](TimeOfDayCondition.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


